.. _user_guide_ref:

User guide
==========

The following tutorials allow you to get started and explore the possibilities offered by this package.

.. toctree::
   :maxdepth: 2

   Covariances <notebooks/examples_covariances>
   Priors <notebooks/examples_priors>

* :ref:`genindex`
